@@ -22,7 +22,6 @@ package org.apache.myfaces.tobago.internal.taglib.component;
 import org.apache.myfaces.tobago.apt.annotation.Behavior;
 import org.apache.myfaces.tobago.apt.annotation.BodyContentDescription;
 import org.apache.myfaces.tobago.apt.annotation.Facet;
-import org.apache.myfaces.tobago.apt.annotation.Markup;
 import org.apache.myfaces.tobago.apt.annotation.Tag;
 import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
 import org.apache.myfaces.tobago.component.ClientBehaviors;
@@ -44,6 +43,7 @@ import org.apache.myfaces.tobago.internal.taglib.declaration.HasValidator;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasValidatorMessage;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasValue;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasValueChangeListener;
+import org.apache.myfaces.tobago.internal.taglib.declaration.HasAutoSpacing;
 import org.apache.myfaces.tobago.internal.taglib.declaration.IsDisabled;
 import org.apache.myfaces.tobago.internal.taglib.declaration.IsFocus;
 import org.apache.myfaces.tobago.internal.taglib.declaration.IsPassword;
@@ -78,25 +78,27 @@ import javax.faces.component.UIInput;
         @Behavior(
             name = ClientBehaviors.CHANGE,
             isDefault = true),
+        @Behavior(
+            name = ClientBehaviors.INPUT),
         @Behavior(
             name = ClientBehaviors.CLICK),
         @Behavior(
             name = ClientBehaviors.DBLCLICK),
         @Behavior(
             name = ClientBehaviors.FOCUS),
+        @Behavior(
+            name = ClientBehaviors.KEYDOWN),
+        @Behavior(
+            name = ClientBehaviors.KEYPRESS),
+        @Behavior(
+            name = ClientBehaviors.KEYUP),
         @Behavior(
             name = ClientBehaviors.BLUR)
-    },
-    markups = {
-        @Markup(name = org.apache.myfaces.tobago.context.Markup.STRING_LOCAL_MENU,
-            description = "If a suggest menu is available, it will be rendered on the component, "
-                + "not in the '.tobago-page-menuStore'."
-        )
     })
 public interface InTagDeclaration
     extends HasIdBindingAndRendered, HasConverter, IsReadonly, IsDisabled, IsRequired, HasHelp, HasTip, IsPassword,
     HasAccessKey, HasValidator, HasValue, HasValueChangeListener, HasTabIndex, IsFocus, IsVisual,
     HasValidatorMessage, HasConverterMessage, HasRequiredMessage, HasLabel, HasLabelLayout,
-    HasAutocomplete, HasPlaceholder {
+    HasAutocomplete, HasPlaceholder, HasAutoSpacing {
 
 }
